git: Version control system
===========================

Description
-----------

   Git is a fast, scalable, distributed revision control system with an
   unusually rich command set that provides both high-operations and
   full access to internals.

-  ``man git``


Upstream Contact
----------------

-  Website: https://git-scm.com/
